summaryrefslogtreecommitdiffstats
path: root/kverbos
diff options
context:
space:
mode:
Diffstat (limited to 'kverbos')
-rw-r--r--kverbos/kverbos/kerfassen.cpp26
-rw-r--r--kverbos/kverbos/kerfassen.h4
-rw-r--r--kverbos/kverbos/kfeedercontrol.cpp12
-rw-r--r--kverbos/kverbos/kfeedercontrol.h4
-rw-r--r--kverbos/kverbos/kresult.cpp34
-rw-r--r--kverbos/kverbos/kresult.h2
-rw-r--r--kverbos/kverbos/kstartuplogo.cpp12
-rw-r--r--kverbos/kverbos/kstartuplogo.h8
-rw-r--r--kverbos/kverbos/kverbedit.cpp20
-rw-r--r--kverbos/kverbos/kverbedit.h2
-rw-r--r--kverbos/kverbos/kverbos.cpp100
-rw-r--r--kverbos/kverbos/kverbos.h4
-rw-r--r--kverbos/kverbos/kverbosdoc.cpp54
-rw-r--r--kverbos/kverbos/kverbosdoc.h20
-rw-r--r--kverbos/kverbos/kverbosoptions.cpp6
-rw-r--r--kverbos/kverbos/kverbosoptions.h2
-rw-r--r--kverbos/kverbos/kverbosuser.cpp22
-rw-r--r--kverbos/kverbos/kverbosuser.h18
-rw-r--r--kverbos/kverbos/kverbosview.cpp64
-rw-r--r--kverbos/kverbos/kverbosview.h18
-rw-r--r--kverbos/kverbos/verbspanish.cpp70
-rw-r--r--kverbos/kverbos/verbspanish.h74
22 files changed, 288 insertions, 288 deletions
diff --git a/kverbos/kverbos/kerfassen.cpp b/kverbos/kverbos/kerfassen.cpp
index ea646886..9ae8c2b7 100644
--- a/kverbos/kverbos/kerfassen.cpp
+++ b/kverbos/kverbos/kerfassen.cpp
@@ -17,12 +17,12 @@
#include "kerfassen.h"
-#include <qlineedit.h>
-#include <qlabel.h>
-#include <qcombobox.h>
-#include <qpushbutton.h>
-#include <qtabwidget.h>
-//#include <qvaluelist.h>
+#include <tqlineedit.h>
+#include <tqlabel.h>
+#include <tqcombobox.h>
+#include <tqpushbutton.h>
+#include <tqtabwidget.h>
+//#include <tqvaluelist.h>
#include <kmessagebox.h>
@@ -31,7 +31,7 @@
// Die Konstruktoren sollen sicherstellen, dass am Anfang die Karteikarten und
// die Eingabefelder für Gerund und Partizip nicht aktiviert sind.
// Das Dialogfeld in den Zustand nicht geändert versetzen.
-KErfassen::KErfassen(spanishVerbList& l, int pos, QWidget* parent, const char* name, bool modal, WFlags fl)
+KErfassen::KErfassen(spanishVerbList& l, int pos, TQWidget* parent, const char* name, bool modal, WFlags fl)
: QErfassen(parent, name, modal, fl), liste(l)
{
formEdit[0][0] = EditYo2_1;
@@ -352,42 +352,42 @@ void KErfassen::slotNewVerb()
void KErfassen::slotN()
{
- QLineEdit* pl = dynamic_cast<QLineEdit*>(focusWidget());
+ TQLineEdit* pl = dynamic_cast<TQLineEdit*>(focusWidget());
if (pl)
pl->insert("ñ");
}
void KErfassen::slotA()
{
- QLineEdit* pl = dynamic_cast<QLineEdit*>(focusWidget());
+ TQLineEdit* pl = dynamic_cast<TQLineEdit*>(focusWidget());
if (pl)
pl->insert("á");
}
void KErfassen::slotE()
{
- QLineEdit* pl = dynamic_cast<QLineEdit*>(focusWidget());
+ TQLineEdit* pl = dynamic_cast<TQLineEdit*>(focusWidget());
if (pl)
pl->insert("é");
}
void KErfassen::slotI()
{
- QLineEdit* pl = dynamic_cast<QLineEdit*>(focusWidget());
+ TQLineEdit* pl = dynamic_cast<TQLineEdit*>(focusWidget());
if (pl)
pl->insert("í");
}
void KErfassen::slotO()
{
- QLineEdit* pl = dynamic_cast<QLineEdit*>(focusWidget());
+ TQLineEdit* pl = dynamic_cast<TQLineEdit*>(focusWidget());
if (pl)
pl->insert("ó");
}
void KErfassen::slotU()
{
- QLineEdit* pl = dynamic_cast<QLineEdit*>(focusWidget());
+ TQLineEdit* pl = dynamic_cast<TQLineEdit*>(focusWidget());
if (pl)
pl->insert("ú");
}
diff --git a/kverbos/kverbos/kerfassen.h b/kverbos/kverbos/kerfassen.h
index 7a8f2fc6..15f0b526 100644
--- a/kverbos/kverbos/kerfassen.h
+++ b/kverbos/kverbos/kerfassen.h
@@ -38,7 +38,7 @@ public:
* Verben in die Liste eingefügt werden können. Es wird auch ein Iterator übergeben, der
* anzeigt, wo mit dem editieren begonnen werden soll.
*/
- KErfassen(spanishVerbList& l, int pos = -1, QWidget* parent = 0, const char* name = 0, bool modal = FALSE, WFlags fl = 0);
+ KErfassen(spanishVerbList& l, int pos = -1, TQWidget* parent = 0, const char* name = 0, bool modal = FALSE, WFlags fl = 0);
/** der Destruktor */
virtual ~KErfassen();
/** Gibt zurück, ob durch den Ablauf des Dialoges eine Änderung an der
@@ -142,7 +142,7 @@ private:
/** changed zeigt an, ob etwas geändert wurde. */
bool changed;
/** Are pointers to the GUI elements for an easier use */
- QLineEdit* formEdit[6][MAX_TIEMPOS];
+ TQLineEdit* formEdit[6][MAX_TIEMPOS];
};
#endif
diff --git a/kverbos/kverbos/kfeedercontrol.cpp b/kverbos/kverbos/kfeedercontrol.cpp
index daa4b9ab..8948a128 100644
--- a/kverbos/kverbos/kfeedercontrol.cpp
+++ b/kverbos/kverbos/kfeedercontrol.cpp
@@ -22,8 +22,8 @@
KFeederControl::KFeederControl(int ID, bool splash, bool automatic)
{
- QString f = KStandardDirs::findExe("kfeeder");
- QString s;
+ TQString f = KStandardDirs::findExe("kfeeder");
+ TQString s;
s.setNum(ID);
childFeeder << f;
if (splash)
@@ -57,7 +57,7 @@ bool KFeederControl::reset()
{
if (active)
{
- QByteArray data; // "raw support" for data
+ TQByteArray data; // "raw support" for data
QDataStream arg(data, IO_WriteOnly); // "container" provides
// easy access to data
int a_number = 1;
@@ -77,7 +77,7 @@ bool KFeederControl::addOne()
{
if (active)
{
- QByteArray data; // "raw support" for data
+ TQByteArray data; // "raw support" for data
QDataStream arg(data, IO_WriteOnly); // "container" provides
// easy access to data
int a_number = 1;
@@ -97,7 +97,7 @@ bool KFeederControl::addN(int n)
{
if (active)
{
- QByteArray data; // "raw support" for data
+ TQByteArray data; // "raw support" for data
QDataStream arg(data, IO_WriteOnly); // "container" provides
// easy access to data
int a_number = n;
@@ -119,7 +119,7 @@ bool KFeederControl::setAutomatic(bool a)
{
if (active)
{
- QByteArray data; // "raw support" for data
+ TQByteArray data; // "raw support" for data
QDataStream arg(data, IO_WriteOnly); // "container" provides
// easy access to data
int num;
diff --git a/kverbos/kverbos/kfeedercontrol.h b/kverbos/kverbos/kfeedercontrol.h
index 9617aa18..635a6311 100644
--- a/kverbos/kverbos/kfeedercontrol.h
+++ b/kverbos/kverbos/kfeedercontrol.h
@@ -47,11 +47,11 @@ public:
bool getLastResult() { return lastResult; }
private:
KProcess childFeeder;
- QCString feederID;
+ TQCString feederID;
bool active;
bool lastResult;
- QCString appId;
+ TQCString appId;
DCOPClient* dcop;
};
diff --git a/kverbos/kverbos/kresult.cpp b/kverbos/kverbos/kresult.cpp
index eeaedb6b..2eb5b6c1 100644
--- a/kverbos/kverbos/kresult.cpp
+++ b/kverbos/kverbos/kresult.cpp
@@ -16,21 +16,21 @@
***************************************************************************/
#include "kresult.h"
-#include <qlabel.h>
-#include <qtable.h>
-#include <qlistview.h>
-#include <qvaluestack.h>
+#include <tqlabel.h>
+#include <tqtable.h>
+#include <tqlistview.h>
+#include <tqvaluestack.h>
#include <klocale.h>
-KResult::KResult(KVerbosUser* pU, QWidget* parent, const char* name, bool modal, WFlags fl )
+KResult::KResult(KVerbosUser* pU, TQWidget* parent, const char* name, bool modal, WFlags fl )
: QResult(parent, name, modal, fl)
{
int sessions;
- QString date[10];
+ TQString date[10];
int result[10][2];
pU->getResults(sessions, date, result);
- QString s;
+ TQString s;
s.setNum(sessions);
TextLabelSessions->setText(s);
TextLabelUser->setText(pU->getName());
@@ -48,13 +48,13 @@ KResult::KResult(KVerbosUser* pU, QWidget* parent, const char* name, bool modal,
TableResult->adjustColumn(2);
// Die Spaltenbreiten anpassen
- ListViewVerben->setColumnWidthMode(0, QListView::Maximum);
- ListViewVerben->setColumnWidthMode(1, QListView::Maximum);
+ ListViewVerben->setColumnWidthMode(0, TQListView::Maximum);
+ ListViewVerben->setColumnWidthMode(1, TQListView::Maximum);
verbenListe* pVL = pU->getListe();
verbenListe::Iterator it;
- QValueStack<QString> right;
- QValueStack<QString> wrong;
+ TQValueStack<TQString> right;
+ TQValueStack<TQString> wrong;
for (it = pVL->begin(); it!=pVL->end(); ++it)
{
if ((*it).status == RICHTIGGEMACHT)
@@ -65,20 +65,20 @@ KResult::KResult(KVerbosUser* pU, QWidget* parent, const char* name, bool modal,
};
while (!right.isEmpty() && !wrong.isEmpty())
{
- QListViewItem* pItem;
- pItem = new QListViewItem( ListViewVerben, right.pop(), wrong.pop());
+ TQListViewItem* pItem;
+ pItem = new TQListViewItem( ListViewVerben, right.pop(), wrong.pop());
ListViewVerben->insertItem(pItem);
};
while (!right.isEmpty())
{
- QListViewItem* pItem;
- pItem = new QListViewItem( ListViewVerben, right.pop(), "");
+ TQListViewItem* pItem;
+ pItem = new TQListViewItem( ListViewVerben, right.pop(), "");
ListViewVerben->insertItem(pItem);
};
while (!wrong.isEmpty())
{
- QListViewItem* pItem;
- pItem = new QListViewItem( ListViewVerben, "", wrong.pop());
+ TQListViewItem* pItem;
+ pItem = new TQListViewItem( ListViewVerben, "", wrong.pop());
ListViewVerben->insertItem(pItem);
};
}
diff --git a/kverbos/kverbos/kresult.h b/kverbos/kverbos/kresult.h
index bcf54f97..e4aee250 100644
--- a/kverbos/kverbos/kresult.h
+++ b/kverbos/kverbos/kresult.h
@@ -28,7 +28,7 @@
class KResult : public QResult {
public:
- KResult(KVerbosUser* pU, QWidget* parent = 0, const char* name = 0, bool modal = FALSE, WFlags fl = 0 );
+ KResult(KVerbosUser* pU, TQWidget* parent = 0, const char* name = 0, bool modal = FALSE, WFlags fl = 0 );
~KResult();
public slots:
/** Wird durch den OK-Button aufgerufen und beendet den Dialog.
diff --git a/kverbos/kverbos/kstartuplogo.cpp b/kverbos/kverbos/kstartuplogo.cpp
index 40569b0b..b01088ec 100644
--- a/kverbos/kverbos/kstartuplogo.cpp
+++ b/kverbos/kverbos/kstartuplogo.cpp
@@ -20,13 +20,13 @@
#include <kstandarddirs.h>
#include <kglobalsettings.h>
-KStartupLogo::KStartupLogo(QWidget * parent, const char *name)
-: QWidget(parent,name,WStyle_Customize | WStyle_NoBorder )
+KStartupLogo::KStartupLogo(TQWidget * parent, const char *name)
+: TQWidget(parent,name,WStyle_Customize | WStyle_NoBorder )
{
- QPixmap pm;
+ TQPixmap pm;
pm.load(locate("appdata", "pics/startuplogo.png"));
setBackgroundPixmap(pm);
- QRect desk = KGlobalSettings::splashScreenDesktopGeometry();
+ TQRect desk = KGlobalSettings::splashScreenDesktopGeometry();
setGeometry(desk.center().x()-pm.width()/2, desk.center().y()-pm.height()/2,
pm.width(),pm.height());
}
@@ -34,9 +34,9 @@ KStartupLogo::KStartupLogo(QWidget * parent, const char *name)
KStartupLogo::~KStartupLogo(){
}
-bool KStartupLogo::event(QEvent* ev){
+bool KStartupLogo::event(TQEvent* ev){
raise();
- return QWidget::event(ev);
+ return TQWidget::event(ev);
}
#include "kstartuplogo.moc"
diff --git a/kverbos/kverbos/kstartuplogo.h b/kverbos/kverbos/kstartuplogo.h
index 792e9272..c290cc0a 100644
--- a/kverbos/kverbos/kstartuplogo.h
+++ b/kverbos/kverbos/kstartuplogo.h
@@ -18,19 +18,19 @@
#ifndef KSTARTUPLOGO_H
#define KSTARTUPLOGO_H
-#include <qwidget.h>
+#include <tqwidget.h>
/**This class creates the splash screen at the beginning of the program.
*@author Arnold Kraschinski
*/
-class KStartupLogo : public QWidget {
+class KStartupLogo : public TQWidget {
Q_OBJECT
public:
- KStartupLogo(QWidget *parent=0, const char *name=0);
+ KStartupLogo(TQWidget *parent=0, const char *name=0);
~KStartupLogo();
protected:
- virtual bool event(QEvent*);
+ virtual bool event(TQEvent*);
};
diff --git a/kverbos/kverbos/kverbedit.h b/kverbos/kverbos/kverbedit.h
index 23057ed1..e3b84d56 100644
--- a/kverbos/kverbos/kverbedit.h
+++ b/kverbos/kverbos/kverbedit.h
@@ -34,7 +34,7 @@ public:
/** An die Dialogklasse wird direkt die Verbliste übergeben, damit
* die Liste der Verben bearbeitet werden kann.
*/
- KVerbEdit(spanishVerbList& l, QWidget* parent = 0, const char* name = 0, bool modal = FALSE, WFlags fl = 0);
+ KVerbEdit(spanishVerbList& l, TQWidget* parent = 0, const char* name = 0, bool modal = FALSE, WFlags fl = 0);
~KVerbEdit();
/** kopiert die Liste in die ListView. */
void listToView();
diff --git a/kverbos/kverbos/kverbos.cpp b/kverbos/kverbos/kverbos.cpp
index 2a5198cf..96d6930a 100644
--- a/kverbos/kverbos/kverbos.cpp
+++ b/kverbos/kverbos/kverbos.cpp
@@ -16,9 +16,9 @@
***************************************************************************/
// include files for QT
-#include <qprinter.h>
-#include <qcheckbox.h>
-#include <qradiobutton.h>
+#include <tqprinter.h>
+#include <tqcheckbox.h>
+#include <tqradiobutton.h>
// include files for KDE
#include <kfiledialog.h>
@@ -48,7 +48,7 @@
int KVerbosApp::kverbosCounter = 0;
-KVerbosApp::KVerbosApp(QWidget* , const char* name):KMainWindow (0, name)
+KVerbosApp::KVerbosApp(TQWidget* , const char* name):KMainWindow (0, name)
{
// als erstes das Logo starten
KStartupLogo* start_logo = new KStartupLogo(0);
@@ -108,7 +108,7 @@ KVerbosApp::~KVerbosApp()
kverbosCounter--;
if (kfeederControl)
{
- disconnect(view, SIGNAL(informKFeeder(int)), this, SLOT(slotFeedIt(int)));
+ disconnect(view, TQT_SIGNAL(informKFeeder(int)), this, TQT_SLOT(slotFeedIt(int)));
delete kfeederControl;
kfeederControl = 0;
};
@@ -116,25 +116,25 @@ KVerbosApp::~KVerbosApp()
void KVerbosApp::initActions()
{
- fileNewWindow = new KAction(i18n("New &Window"), "window_new.png", 0, this, SLOT(slotFileNewWindow()), actionCollection(),"file_new_window");
- fileNew = KStdAction::openNew(this, SLOT(slotFileNew()), actionCollection());
- fileOpen = KStdAction::open(this, SLOT(slotFileOpen()), actionCollection());
- fileOpenRecent = KStdAction::openRecent(this, SLOT(slotFileOpenRecent(const KURL&)), actionCollection());
- fileOpenStandard = new KAction(i18n("Open &Standard Verb File"), "fileopen.png", 0, this, SLOT(slotFileOpenStandard()), actionCollection(),"file_open_standard");
- fileSave = KStdAction::save(this, SLOT(slotFileSave()), actionCollection());
- fileSaveAs = KStdAction::saveAs(this, SLOT(slotFileSaveAs()), actionCollection());
- fileClose = KStdAction::close(this, SLOT(slotFileClose()), actionCollection());
- filePrint = KStdAction::print(this, SLOT(slotFilePrint()), actionCollection());
- fileQuit = KStdAction::quit(this, SLOT(slotFileQuit()), actionCollection());
- editCut = KStdAction::cut(this, SLOT(slotEditCut()), actionCollection());
- editCopy = KStdAction::copy(this, SLOT(slotEditCopy()), actionCollection());
- editPaste = KStdAction::paste(this, SLOT(slotEditPaste()), actionCollection());
- editErfassen = new KAction(i18n("E&nter New Verb..."), 0, 0, this, SLOT(slotEditErfassen()), actionCollection(),"edit_erfassen");
- editBearbeiten = new KAction(i18n("&Edit Verb List..."), 0, 0, this, SLOT(slotEditBearbeiten()), actionCollection(), "edit_bearbeiten");
-
- settingOptions = new KAction(i18n("&Configure KVerbos..."), 0, 0, this, SLOT(slotSettingsOptions()), actionCollection(), "settings_options");
- userUsername = new KAction(i18n("&Username..."), 0, 0, this, SLOT(slotSettingsUsername()), actionCollection(), "user_username");
- userResults = new KAction(i18n("&Results"), 0, 0, this, SLOT(slotUserResults()), actionCollection(), "user_results");
+ fileNewWindow = new KAction(i18n("New &Window"), "window_new.png", 0, this, TQT_SLOT(slotFileNewWindow()), actionCollection(),"file_new_window");
+ fileNew = KStdAction::openNew(this, TQT_SLOT(slotFileNew()), actionCollection());
+ fileOpen = KStdAction::open(this, TQT_SLOT(slotFileOpen()), actionCollection());
+ fileOpenRecent = KStdAction::openRecent(this, TQT_SLOT(slotFileOpenRecent(const KURL&)), actionCollection());
+ fileOpenStandard = new KAction(i18n("Open &Standard Verb File"), "fileopen.png", 0, this, TQT_SLOT(slotFileOpenStandard()), actionCollection(),"file_open_standard");
+ fileSave = KStdAction::save(this, TQT_SLOT(slotFileSave()), actionCollection());
+ fileSaveAs = KStdAction::saveAs(this, TQT_SLOT(slotFileSaveAs()), actionCollection());
+ fileClose = KStdAction::close(this, TQT_SLOT(slotFileClose()), actionCollection());
+ filePrint = KStdAction::print(this, TQT_SLOT(slotFilePrint()), actionCollection());
+ fileQuit = KStdAction::quit(this, TQT_SLOT(slotFileQuit()), actionCollection());
+ editCut = KStdAction::cut(this, TQT_SLOT(slotEditCut()), actionCollection());
+ editCopy = KStdAction::copy(this, TQT_SLOT(slotEditCopy()), actionCollection());
+ editPaste = KStdAction::paste(this, TQT_SLOT(slotEditPaste()), actionCollection());
+ editErfassen = new KAction(i18n("E&nter New Verb..."), 0, 0, this, TQT_SLOT(slotEditErfassen()), actionCollection(),"edit_erfassen");
+ editBearbeiten = new KAction(i18n("&Edit Verb List..."), 0, 0, this, TQT_SLOT(slotEditBearbeiten()), actionCollection(), "edit_bearbeiten");
+
+ settingOptions = new KAction(i18n("&Configure KVerbos..."), 0, 0, this, TQT_SLOT(slotSettingsOptions()), actionCollection(), "settings_options");
+ userUsername = new KAction(i18n("&Username..."), 0, 0, this, TQT_SLOT(slotSettingsUsername()), actionCollection(), "user_username");
+ userResults = new KAction(i18n("&Results"), 0, 0, this, TQT_SLOT(slotUserResults()), actionCollection(), "user_results");
fileNewWindow->setToolTip(i18n("Opens a new application window"));
fileOpenStandard->setToolTip(i18n("Opens the standard KVerbos verb file"));
@@ -182,8 +182,8 @@ void KVerbosApp::initDocument()
{
doc = new KVerbosDoc(this);
doc->newDocument();
- connect(doc, SIGNAL(anzahlVerbenGeaendert(int)), this, SLOT(slotStatusVerbMsg(int)));
- connect(this, SIGNAL(testAnzahl(int)), this, SLOT(slotStatusVerbMsg(int)));
+ connect(doc, TQT_SIGNAL(anzahlVerbenGeaendert(int)), this, TQT_SLOT(slotStatusVerbMsg(int)));
+ connect(this, TQT_SIGNAL(testAnzahl(int)), this, TQT_SLOT(slotStatusVerbMsg(int)));
}
void KVerbosApp::initView()
@@ -197,9 +197,9 @@ void KVerbosApp::initView()
setCentralWidget(view);
setCaption(doc->URL().fileName(),false);
//
- connect(view, SIGNAL(numberTrainedChanged(int)), this, SLOT(slotStatusTrainedMsg(int)));
- connect(view, SIGNAL(numberCorrectChanged(int)), this, SLOT(slotStatusCorrectMsg(int)));
- connect(view, SIGNAL(informKFeeder(int)), this, SLOT(slotFeedIt(int)));
+ connect(view, TQT_SIGNAL(numberTrainedChanged(int)), this, TQT_SLOT(slotStatusTrainedMsg(int)));
+ connect(view, TQT_SIGNAL(numberCorrectChanged(int)), this, TQT_SLOT(slotStatusCorrectMsg(int)));
+ connect(view, TQT_SIGNAL(informKFeeder(int)), this, TQT_SLOT(slotFeedIt(int)));
}
void KVerbosApp::openDocumentFile(const KURL& url)
@@ -224,11 +224,11 @@ void KVerbosApp::saveOptions()
// Meine eigenen Optionen
// Die zum Lernen ausgewählten Zeiten
config->setGroup("tiempos");
- QString key;
+ TQString key;
for (int i = presente; i<MAX_TIEMPOS; i++)
{
key.setNum(i);
- QString options = timeOptions[i][0] ? "true " : "false ";
+ TQString options = timeOptions[i][0] ? "true " : "false ";
options = timeOptions[i][1] ? options + "true " : options + "false ";
options = timeOptions[i][2] ? options + "true" : options + "false";
config->writeEntry(key, options);
@@ -252,11 +252,11 @@ void KVerbosApp::readOptions()
// Meine eigenen Optionen
// Die zum Lernen ausgewählten Zeiten
config->setGroup("tiempos");
- QString key;
+ TQString key;
for (int i = presente; i<MAX_TIEMPOS; i++)
{
key.setNum(i);
- QString options = config->readEntry ( key, "true false false");
+ TQString options = config->readEntry ( key, "true false false");
int pos1 = 0;
int pos2 = options.find (' ', pos1, false);
timeOptions[i][0] = (options.left(pos2) == "true") ? true : false;
@@ -295,8 +295,8 @@ void KVerbosApp::saveProperties(KConfig *_cfg)
KURL url=doc->URL();
_cfg->writePathEntry("filename", url.url());
_cfg->writeEntry("modified", doc->isModified());
- QString tempname = kapp->tempSaveName(url.url());
- QString tempurl= KURL::encode_string(tempname);
+ TQString tempname = kapp->tempSaveName(url.url());
+ TQString tempurl= KURL::encode_string(tempname);
KURL _url(tempurl);
doc->saveDocument(_url);
}
@@ -305,20 +305,20 @@ void KVerbosApp::saveProperties(KConfig *_cfg)
void KVerbosApp::readProperties(KConfig* _cfg)
{
- QString filename = _cfg->readPathEntry("filename");
+ TQString filename = _cfg->readPathEntry("filename");
KURL url(filename);
bool modified = _cfg->readBoolEntry("modified", false);
if(modified)
{
bool canRecover;
- QString tempname = kapp->checkRecoverFile(filename, canRecover);
+ TQString tempname = kapp->checkRecoverFile(filename, canRecover);
KURL _url(tempname);
if(canRecover)
{
doc->openDocument(_url);
doc->setModified();
setCaption(_url.fileName(),true);
- QFile::remove(tempname);
+ TQFile::remove(tempname);
}
}
else
@@ -343,7 +343,7 @@ bool KVerbosApp::queryExit()
}
/////////////////////////////////////////////////////////////////////
-// SLOT IMPLEMENTATION
+// TQT_SLOT IMPLEMENTATION
/////////////////////////////////////////////////////////////////////
void KVerbosApp::slotFileNewWindow()
@@ -385,7 +385,7 @@ void KVerbosApp::slotFileOpen()
}
else
{
- KURL url=KFileDialog::getOpenURL(QString::null,
+ KURL url=KFileDialog::getOpenURL(TQString::null,
i18n("*|All Files"), this, i18n("Open File"));
if(!url.isEmpty())
{
@@ -420,7 +420,7 @@ void KVerbosApp::slotFileOpenRecent(const KURL& url)
void KVerbosApp::slotFileOpenStandard()
{
slotStatusMsg(i18n("Opening file..."));
- QString userLanguage = Prefs::userLanguage();
+ TQString userLanguage = Prefs::userLanguage();
if(!doc->saveModified())
{
// here saving wasn't successful
@@ -460,7 +460,7 @@ void KVerbosApp::slotFileSaveAs()
{
slotStatusMsg(i18n("Saving file with a new filename..."));
- KURL url=KFileDialog::getSaveURL(QDir::currentDirPath(),
+ KURL url=KFileDialog::getSaveURL(TQDir::currentDirPath(),
i18n("*|All Files"), this, i18n("Save As"));
if(!url.isEmpty())
{
@@ -485,7 +485,7 @@ void KVerbosApp::slotFilePrint()
{
slotStatusMsg(i18n("Printing..."));
- QPrinter printer;
+ TQPrinter printer;
if (printer.setup(this))
{
view->print(&printer);
@@ -536,7 +536,7 @@ void KVerbosApp::slotEditPaste()
slotStatusMsg(i18n("Ready."));
}
-void KVerbosApp::slotStatusMsg(const QString &text)
+void KVerbosApp::slotStatusMsg(const TQString &text)
{
///////////////////////////////////////////////////////////////////
// change status message permanently
@@ -547,7 +547,7 @@ void KVerbosApp::slotStatusMsg(const QString &text)
// Gibt die Anzahl der Verben in der Statuszeile aus
void KVerbosApp::slotStatusVerbMsg(int n)
{
- QString s;
+ TQString s;
s.setNum(n,10);
s = i18n("Number of verbs: ") + s;
statusBar()->changeItem(s, ID_VERBS_MSG);
@@ -556,7 +556,7 @@ void KVerbosApp::slotStatusVerbMsg(int n)
// Gibt die Anzahl der geübten Verben in der Statuszeile aus.
void KVerbosApp::slotStatusTrainedMsg(int n)
{
- QString s;
+ TQString s;
s.setNum(n,10);
s = i18n("Trained: ") + s;
statusBar()->changeItem(s, ID_TRAINED_MSG);
@@ -565,7 +565,7 @@ void KVerbosApp::slotStatusTrainedMsg(int n)
// Gibt die Anzahl der richtig geübten Verben aus.
void KVerbosApp::slotStatusCorrectMsg(int n)
{
- QString s;
+ TQString s;
s.setNum(n,10);
s = i18n("Correct: ") + s;
statusBar()->changeItem(s, ID_CORRECT_MSG);
@@ -710,7 +710,7 @@ void KVerbosApp::slotSettingsOptions()
if ((pDlgEdit->CheckBoxKFeeder->isChecked() == false) && (useKFeeder))
{
// kfeeder anhalten
- disconnect(view, SIGNAL(informKFeeder(int)), this, SLOT(slotFeedIt(int)));
+ disconnect(view, TQT_SIGNAL(informKFeeder(int)), this, TQT_SLOT(slotFeedIt(int)));
delete kfeederControl;
kfeederControl = 0;
};
@@ -730,8 +730,8 @@ void KVerbosApp::getTimeOptions(bool op[][3])
void KVerbosApp::slotSettingsUsername()
{
bool ok;
- QString n = KInputDialog::getText(i18n("Enter User Name"), i18n("Please enter your name:"),
- QString::null , &ok, this).simplifyWhiteSpace();
+ TQString n = KInputDialog::getText(i18n("Enter User Name"), i18n("Please enter your name:"),
+ TQString::null , &ok, this).simplifyWhiteSpace();
if (ok)
{
statusBar()->changeItem(i18n("user: ") + n, ID_USERNAME_MSG);
diff --git a/kverbos/kverbos/kverbos.h b/kverbos/kverbos/kverbos.h
index b31bf12a..982ee0c1 100644
--- a/kverbos/kverbos/kverbos.h
+++ b/kverbos/kverbos/kverbos.h
@@ -63,7 +63,7 @@ class KVerbosApp : public KMainWindow
public:
/** construtor of KVerbosApp, calls all init functions to create the application.
*/
- KVerbosApp(QWidget* parent=0, const char* name=0);
+ KVerbosApp(TQWidget* parent=0, const char* name=0);
~KVerbosApp();
/** opens a file specified by commandline option
*/
@@ -164,7 +164,7 @@ class KVerbosApp : public KMainWindow
* current actions.
* @param text the text that is displayed in the statusbar
*/
- void slotStatusMsg(const QString &text);
+ void slotStatusMsg(const TQString &text);
/** Gibt die Anzahl der Verben in der Statuszeile aus */
void slotStatusVerbMsg(int);
/** Gibt die Anzahl der geübten Verben in der Statuszeile aus.
diff --git a/kverbos/kverbos/kverbosdoc.cpp b/kverbos/kverbos/kverbosdoc.cpp
index 9e4cc408..632f10b3 100644
--- a/kverbos/kverbos/kverbosdoc.cpp
+++ b/kverbos/kverbos/kverbosdoc.cpp
@@ -21,7 +21,7 @@
#include <cstdlib>
// include files for Qt
-#include <qmessagebox.h>
+#include <tqmessagebox.h>
// include files for KDE
#include <klocale.h>
@@ -37,13 +37,13 @@
-QPtrList<KVerbosView> *KVerbosDoc::pViewList = 0L;
+TQPtrList<KVerbosView> *KVerbosDoc::pViewList = 0L;
-KVerbosDoc::KVerbosDoc(QWidget *parent, const char *name) : QObject(parent, name)
+KVerbosDoc::KVerbosDoc(TQWidget *parent, const char *name) : TQObject(parent, name)
{
if(!pViewList)
{
- pViewList = new QPtrList<KVerbosView>();
+ pViewList = new TQPtrList<KVerbosView>();
};
pViewList->setAutoDelete(true);
// Zufallsgenerator mit einem seed-Wert versorgen
@@ -68,7 +68,7 @@ KVerbosDoc::~KVerbosDoc()
void KVerbosDoc::addView(KVerbosView *view)
{
pViewList->append(view);
- connect(this, SIGNAL(changeView()), view, SLOT(zeigeVerb()));
+ connect(this, TQT_SIGNAL(changeView()), view, TQT_SLOT(zeigeVerb()));
}
void KVerbosDoc::removeView(KVerbosView *view)
@@ -159,10 +159,10 @@ bool KVerbosDoc::newDocument()
bool KVerbosDoc::openDocument(const KURL& url, const char *format /*=0*/)
{
bool b = false;
- QString tmpfile;
+ TQString tmpfile;
KIO::NetAccess::download( url, tmpfile );
- QFile file(url.path());
+ TQFile file(url.path());
if ( file.open(IO_ReadOnly) ) { // file opened successfully
deleteContents();
if ((url.fileName().right(4) == "html")||(url.fileName().right(3) == "htm"))
@@ -213,15 +213,15 @@ bool KVerbosDoc::openDocument(const KURL& url, const char *format /*=0*/)
}
// Liesteine Datei als HTML-Dokument ein
-bool KVerbosDoc::openDocHTML(QFile &f)
+bool KVerbosDoc::openDocHTML(TQFile &f)
{
bool result = true;
- QTextStream t( &f ); // use a text stream
+ TQTextStream t( &f ); // use a text stream
int count1;
int count2;
- QString s;
- QString v[3];
- QString forms[60];
+ TQString s;
+ TQString v[3];
+ TQString forms[60];
verbSpanish NewVerb;
while (!f.atEnd())
{
@@ -361,11 +361,11 @@ bool KVerbosDoc::openDocHTML(QFile &f)
return result;
}
-bool KVerbosDoc::openDocVERBOS(QFile &f)
+bool KVerbosDoc::openDocVERBOS(TQFile &f)
{
- QTextStream t( &f ); // use a text stream
+ TQTextStream t( &f ); // use a text stream
int count;
- QString v[3];
+ TQString v[3];
while (!f.atEnd())
{
count = 0;
@@ -403,8 +403,8 @@ bool KVerbosDoc::openDocVERBOS(QFile &f)
};
if (count < 54)
{
- QMessageBox mb("kverbos warning", "An uncomplete verb has been found in the file",
- QMessageBox::Warning, 1, 0, 0, 0);
+ TQMessageBox mb("kverbos warning", "An uncomplete verb has been found in the file",
+ TQMessageBox::Warning, 1, 0, 0, 0);
mb.exec();
//qWarning("Ein unvollständiges Verb kam vor!");
};
@@ -420,7 +420,7 @@ bool KVerbosDoc::openDocVERBOS(QFile &f)
bool KVerbosDoc::saveDocument(const KURL& url, const char *format /*=0*/)
{
bool b = false;
- QFile file(url.path());
+ TQFile file(url.path());
if ( file.open(IO_WriteOnly) )
{ // file opened successfully
if ((url.fileName().right(4) == "html")||(url.fileName().right(3) == "htm"))
@@ -440,10 +440,10 @@ bool KVerbosDoc::saveDocument(const KURL& url, const char *format /*=0*/)
}
// Die Verben als HTML-Datei abspeichern
-bool KVerbosDoc::saveDocHTML(QFile &f)
+bool KVerbosDoc::saveDocHTML(TQFile &f)
{
bool good = true;
- QTextStream t( &f ); // use a text stream
+ TQTextStream t( &f ); // use a text stream
// Den Anfang der HTML Datei schreiben
t << "<html>" << endl;
t << "<head>" << endl;
@@ -616,9 +616,9 @@ bool KVerbosDoc::saveDocHTML(QFile &f)
return good;
}
-bool KVerbosDoc::saveDocVERBOS(QFile &f)
+bool KVerbosDoc::saveDocVERBOS(TQFile &f)
{
- QTextStream t( &f ); // use a text stream
+ TQTextStream t( &f ); // use a text stream
// Die Verbenliste in die Datei schreiben.
if (verbList2.isEmpty())
{
@@ -682,7 +682,7 @@ spanishVerbList* KVerbosDoc::getList()
// Reihenfolge in dem Stringfeld: yo, tu, el, nosotros, vosotros, ellos, aleman, espanol
// Wird "- - - - - -" zurückgegeben, dann gibt es kein Verb in der Liste. Normalerweise
// wird die spanische Verbform zurückgegeben.
-QString KVerbosDoc::getAuswahl(QString s[][3], int &t)
+TQString KVerbosDoc::getAuswahl(TQString s[][3], int &t)
{
bool verbOK = true;
// feststellen, wie viele aktivierte Zeiten in den Optionen vorhanden sind
@@ -732,8 +732,8 @@ QString KVerbosDoc::getAuswahl(QString s[][3], int &t)
};
if (!verbOK)
{
- QMessageBox mb("kverbos warning", "There is a problem with the verb " + s[6][0] +
- ".\nPlease check the verb in the edit dialog.", QMessageBox::Warning, 1, 0, 0, 0);
+ TQMessageBox mb("kverbos warning", "There is a problem with the verb " + s[6][0] +
+ ".\nPlease check the verb in the edit dialog.", TQMessageBox::Warning, 1, 0, 0, 0);
mb.exec();
for (int i=0; i<PERSONEN+1; i++)
{
@@ -746,7 +746,7 @@ QString KVerbosDoc::getAuswahl(QString s[][3], int &t)
return s[6][1];
}
-spanishVerbList::Iterator KVerbosDoc::findVerb(const QString& s)
+spanishVerbList::Iterator KVerbosDoc::findVerb(const TQString& s)
{
spanishVerbList::Iterator it = verbList2.begin();
while ((it != verbList2.end()) && (!((*it) == s)))
@@ -766,7 +766,7 @@ void KVerbosDoc::solved(const bool b)
// sets a new user name, and deletes the old one. If the old one is differet from
// the default name'-------' then some information is stored about the user. The
// Program look if some information about the user is stored.
-void KVerbosDoc::setNewUser(const QString n)
+void KVerbosDoc::setNewUser(const TQString n)
{
if (0 != benutzer)
{
diff --git a/kverbos/kverbos/kverbosdoc.h b/kverbos/kverbos/kverbosdoc.h
index f23033c7..efe5d98c 100644
--- a/kverbos/kverbos/kverbosdoc.h
+++ b/kverbos/kverbos/kverbosdoc.h
@@ -23,7 +23,7 @@
#endif
// include files for QT
-#include <qfile.h>
+#include <tqfile.h>
// include files for KDE
#include <kurl.h>
@@ -65,7 +65,7 @@ class KVerbosDoc : public QObject
/**
* Constructor for the fileclass of the application
*/
- KVerbosDoc(QWidget *parent, const char *name=0);
+ KVerbosDoc(TQWidget *parent, const char *name=0);
/**
* Destructor for the fileclass of the application
*/
@@ -92,21 +92,21 @@ class KVerbosDoc : public QObject
* schieden
*/
bool openDocument(const KURL& url, const char *format=0);
- bool openDocHTML(QFile &f);
- bool openDocVERBOS(QFile &f);
+ bool openDocHTML(TQFile &f);
+ bool openDocVERBOS(TQFile &f);
/** saves the document under filename and format.
* Die Datei kann wahlweise im HTML-Format oder als normale Textdatei abgespeichert
* werden. Die HTML-Datei ist umfangreicher, weil der formatierende HTML-Code
* ergänzt werden muss.
*/
bool saveDocument(const KURL& url, const char *format=0);
- bool saveDocHTML(QFile &f);
- bool saveDocVERBOS(QFile &f);
+ bool saveDocHTML(TQFile &f);
+ bool saveDocVERBOS(TQFile &f);
/** sets a new user name, and deletes the old one. If the old one is different from
* the default name DEFAULTUSER then some information is stored about the user. The
* Program look if some information about the user is stored.
*/
- void setNewUser(const QString n);
+ void setNewUser(const TQString n);
/** returns a pointer to the actual user object */
KVerbosUser* getUser() { return benutzer; }
/** returns the KURL of the document */
@@ -126,12 +126,12 @@ class KVerbosDoc : public QObject
/** Gibt die gewählte Zeit, die Formen des Verbes dazu und den spanischen
* und deutschen Infinitiv zurück
*/
- QString getAuswahl(QString s[][3], int &t);
+ TQString getAuswahl(TQString s[][3], int &t);
/** feedback from the view class about the solution */
void solved(const bool b);
private:
/** searches the verb given as a string in the list and returns a pointer to the verb */
- spanishVerbList::Iterator findVerb(const QString& s);
+ spanishVerbList::Iterator findVerb(const TQString& s);
signals:
/** wird emittiert, wenn sich die Anzahl der Verben im Dokument verändert hat */
@@ -149,7 +149,7 @@ class KVerbosDoc : public QObject
/**
* the list of the views currently connected to the document
*/
- static QPtrList<KVerbosView> *pViewList;
+ static TQPtrList<KVerbosView> *pViewList;
private:
/**
diff --git a/kverbos/kverbos/kverbosoptions.cpp b/kverbos/kverbos/kverbosoptions.cpp
index 872888ea..381e058b 100644
--- a/kverbos/kverbos/kverbosoptions.cpp
+++ b/kverbos/kverbos/kverbosoptions.cpp
@@ -15,11 +15,11 @@
* *
***************************************************************************/
-#include "qlabel.h"
-#include "qcheckbox.h"
+#include "tqlabel.h"
+#include "tqcheckbox.h"
#include "kverbosoptions.h"
-KVerbosOptions::KVerbosOptions( QWidget* parent /*= 0*/, const char* name /*= 0*/, bool modal /*= FALSE*/, WFlags fl /*= 0*/ )
+KVerbosOptions::KVerbosOptions( TQWidget* parent /*= 0*/, const char* name /*= 0*/, bool modal /*= FALSE*/, WFlags fl /*= 0*/ )
: QVerbosOptions(parent, name, modal, fl)
{
// some times are disabled because they aren't ready yet.
diff --git a/kverbos/kverbos/kverbosoptions.h b/kverbos/kverbos/kverbosoptions.h
index 2293fac4..25fc91bf 100644
--- a/kverbos/kverbos/kverbosoptions.h
+++ b/kverbos/kverbos/kverbosoptions.h
@@ -27,7 +27,7 @@
class KVerbosOptions : public QVerbosOptions {
public:
- KVerbosOptions( QWidget* parent = 0, const char* name = 0, bool modal = FALSE, WFlags fl = 0 );
+ KVerbosOptions( TQWidget* parent = 0, const char* name = 0, bool modal = FALSE, WFlags fl = 0 );
~KVerbosOptions();
public slots:
diff --git a/kverbos/kverbos/kverbosuser.cpp b/kverbos/kverbos/kverbosuser.cpp
index 7d7d19d0..64d319af 100644
--- a/kverbos/kverbos/kverbosuser.cpp
+++ b/kverbos/kverbos/kverbosuser.cpp
@@ -18,8 +18,8 @@
#include "kverbosuser.h"
#include <cstdlib>
-#include <qfile.h>
-#include <qdatetime.h>
+#include <tqfile.h>
+#include <tqdatetime.h>
#include <kstandarddirs.h>
@@ -29,18 +29,18 @@ bool eintrag::operator== (const eintrag& e) const
return (verb == e.verb);
}
-KVerbosUser::KVerbosUser(spanishVerbList* pL, QString n/*=DEFAULTUSER*/)
+KVerbosUser::KVerbosUser(spanishVerbList* pL, TQString n/*=DEFAULTUSER*/)
: name(n), auswahl(""), sessions(0)
{
// try to read the user-information if there is one.
int pos;
while ((pos = n.find(' ')) != -1)
n.replace(pos, 1, "_");
- QFile file(locateLocal("data", "/kverbos/data/"+name+".kverbos"));
+ TQFile file(locateLocal("data", "/kverbos/data/"+name+".kverbos"));
if ( file.open(IO_ReadOnly) )
{
- QString s;
- QTextStream t( &file );
+ TQString s;
+ TQTextStream t( &file );
name = t.readLine();
s = t.readLine(); sessions = s.toInt();
for (int i=0; i<MAX_RESULTS; i++)
@@ -145,7 +145,7 @@ void KVerbosUser::updateKumulus()
// selects a verb out of the verbs that are in the U and F list. That means a
// verb that hasn't been studied yet or one that was wrong.
-QString KVerbosUser::suggestVerb()
+TQString KVerbosUser::suggestVerb()
{
auswahl = "";
it = liste.end();
@@ -211,10 +211,10 @@ bool KVerbosUser::saveUser(const int& res, const int& num)
int pos;
while ((pos = name.find(' ')) != -1)
name.replace(pos, 1, "_");
- QFile file(locateLocal("data", "/kverbos/data/"+name+".kverbos"));
+ TQFile file(locateLocal("data", "/kverbos/data/"+name+".kverbos"));
if ( file.open(IO_WriteOnly) )
{
- QTextStream t( &file );
+ TQTextStream t( &file );
t << name << endl;
sessions = (num == 0) ? sessions - 1 : sessions;
t << sessions << endl;
@@ -227,7 +227,7 @@ bool KVerbosUser::saveUser(const int& res, const int& num)
};
if (j == 1)
{
- QDate d = QDate::currentDate();
+ TQDate d = TQDate::currentDate();
t << d.toString() << endl;
t << res << endl;
t << num << endl;
@@ -247,7 +247,7 @@ bool KVerbosUser::saveUser(const int& res, const int& num)
return re;
}
-bool KVerbosUser::getResults(int& s, QString d[], int r[][2])
+bool KVerbosUser::getResults(int& s, TQString d[], int r[][2])
{
s = sessions;
for (int i=0; i<MAX_RESULTS; i++)
diff --git a/kverbos/kverbos/kverbosuser.h b/kverbos/kverbos/kverbosuser.h
index 47312c10..11ba9564 100644
--- a/kverbos/kverbos/kverbosuser.h
+++ b/kverbos/kverbos/kverbosuser.h
@@ -45,7 +45,7 @@ class eintrag
{
public:
bool operator== (const eintrag& e) const;
- QString verb;
+ TQString verb;
int right;
int wrong;
int counter;
@@ -53,7 +53,7 @@ public:
bool used;
};
-typedef QValueList<eintrag> verbenListe;
+typedef TQValueList<eintrag> verbenListe;
/** This class holds information about an user of the program. It stores lists of
* verbs. One list for the words that are in the opened verb file and aren't traines yet.
@@ -65,12 +65,12 @@ typedef QValueList<eintrag> verbenListe;
*/
class KVerbosUser {
public:
- KVerbosUser(spanishVerbList* pL, QString n=DEFAULTUSER);
+ KVerbosUser(spanishVerbList* pL, TQString n=DEFAULTUSER);
~KVerbosUser();
/** fills the lists with the verbs that are in the verb list of the main program */
void fillList(spanishVerbList* pL);
/** returns the user name */
- QString getName() { return name; }
+ TQString getName() { return name; }
/** marks all verbs in the R(right) and the F(false) list as unused. That means they can't
* be a suggestion. This are probably verbs that are stored user data but at the moment
* they aren't in the used verb list.
@@ -81,7 +81,7 @@ public:
void updateKumulus();
/** selects a verb out of the verbs that are in the U and F list. That means a
* verb that hasn't been studied yet or one that was wrong. */
-QString suggestVerb();
+TQString suggestVerb();
/** The solution for the suggested verb was right. Now the verb should be deleted from
* the list of unstudied verbs but added to the list with the right verbs.
*/
@@ -93,17 +93,17 @@ QString suggestVerb();
/** Saves all the user information to the $KDEHOME/apps/kverbos/data/username.kverbos file */
bool saveUser(const int& res, const int& num);
/** Retrieve the old results and the number of sessions */
- bool getResults(int& s, QString d[], int r[][2]);
+ bool getResults(int& s, TQString d[], int r[][2]);
/** returns a pointer to the users verb list */
verbenListe* getListe() { return &liste; }
private:
/** name of the user */
- QString name;
+ TQString name;
/** the list of the verbs that the user has workes with */
verbenListe liste;
/** this is the latest selected verb of the list */
- QString auswahl;
+ TQString auswahl;
/** die aufaddierte Summe der gewichteten Verben */
int kumulus;
/** an Iterator for the verb list */
@@ -111,7 +111,7 @@ private:
/** the number of training sessions that the user has made */
int sessions;
/** The results of the last ten seccions */
- QString date[MAX_RESULTS];
+ TQString date[MAX_RESULTS];
int result[MAX_RESULTS][2];
};
diff --git a/kverbos/kverbos/kverbedit.cpp b/kverbos/kverbos/kverbedit.cpp
index b0d4352e..7e7bcde8 100644
--- a/kverbos/kverbos/kverbedit.cpp
+++ b/kverbos/kverbos/kverbedit.cpp
@@ -15,23 +15,23 @@
* *
***************************************************************************/
-#include <qlistview.h>
+#include <tqlistview.h>
#include "kverbedit.h"
#include "kerfassen.h"
/** An die Dialogklasse wird direkt der Zeiger auf die Verbliste bergeben, damit
* die Liste der Verben bearbeitet werden kann. Zu Beginn mssen alle Verben
* aus der Liste in eine dialogeigene Liste und die QListView bertragen werden.
*/
-KVerbEdit::KVerbEdit(spanishVerbList& l, QWidget* parent /*= 0*/, const char* name /*= 0*/, bool modal /*= FALSE*/, WFlags fl /*= 0*/)
+KVerbEdit::KVerbEdit(spanishVerbList& l, TQWidget* parent /*= 0*/, const char* name /*= 0*/, bool modal /*= FALSE*/, WFlags fl /*= 0*/)
: QVerbEdit(parent, name, modal, fl), list(l)
{
// Die Spaltenbreiten anpassen
- ListView1->setColumnWidthMode(0, QListView::Manual);
- ListView1->setColumnWidthMode(1, QListView::Manual);
+ ListView1->setColumnWidthMode(0, TQListView::Manual);
+ ListView1->setColumnWidthMode(1, TQListView::Manual);
int br = width() / 20 * 9;
- QString brstr;
+ TQString brstr;
brstr.setNum(br);
ListView1->setColumnWidth(0, br);
ListView1->setColumnWidth(1, br);
@@ -53,8 +53,8 @@ void KVerbEdit::listToView()
spanishVerbList::Iterator it;
for (it = list.begin(); it != list.end(); ++it)
{
- QListViewItem* pItem;
- pItem = new QListViewItem( ListView1, (*it).getSpanish(), (*it).getForeign());
+ TQListViewItem* pItem;
+ pItem = new TQListViewItem( ListView1, (*it).getSpanish(), (*it).getForeign());
ListView1->insertItem(pItem);
};
};
@@ -82,7 +82,7 @@ void KVerbEdit::slotCancel()
// An den Dialog wird ein Listeniterator bergeben.
void KVerbEdit::slotEditVerb()
{
- QListViewItem* pi = ListView1->selectedItem();
+ TQListViewItem* pi = ListView1->selectedItem();
// it's a sorted list, so binary search works.
// v is not a real verb it is only used for the search. v doesn't have any forms but
// that isn't important to compare.
@@ -126,7 +126,7 @@ void KVerbEdit::slotEditVerb()
// Das in der Listenansicht ausgew�lte Verb wird gel�cht.
void KVerbEdit::slotDelete()
{
- QListViewItem* pi = ListView1->selectedItem();
+ TQListViewItem* pi = ListView1->selectedItem();
if (0 != pi)
{
// Das Listenelement hersuchen
@@ -15,23 +15,23 @@
/** An die Dialogklasse wird direkt der Zeiger auf die Verbliste bergeben, damit
* die Liste der Verben bearbeitet werden kann. Zu Beginn mssen alle Verben
- * aus der Liste in eine dialogeigene Liste und die QListView bertragen werden.
+ * aus der Liste in eine dialogeigene Liste und die TQListView bertragen werden.
*/
diff --git a/kverbos/kverbos/kverbosview.cpp b/kverbos/kverbos/kverbosview.cpp
index a9bb236e..83f184df 100644
--- a/kverbos/kverbos/kverbosview.cpp
+++ b/kverbos/kverbos/kverbosview.cpp
@@ -18,12 +18,12 @@
#include <cstdlib>
// include files for Qt
-#include <qprinter.h>
-#include <qpainter.h>
-#include <qpushbutton.h>
-#include <qlabel.h>
-#include <qlineedit.h>
-#include <qprogressbar.h>
+#include <tqprinter.h>
+#include <tqpainter.h>
+#include <tqpushbutton.h>
+#include <tqlabel.h>
+#include <tqlineedit.h>
+#include <tqprogressbar.h>
// application specific includes
@@ -33,11 +33,11 @@
#include "verbspanish.h"
-KVerbosView::KVerbosView(QWidget *parent, const char *name) : QLernen/*QWidget*/(parent, name)
+KVerbosView::KVerbosView(TQWidget *parent, const char *name) : QLernen/*TQWidget*/(parent, name)
{
// Hier wird gesetzt, wie der Hintergrund des Fensters zu zeichnen ist.
setBackgroundMode(PaletteBackground);
// Die gesamten Zeiger auf QLineEdit in ein Feld umwandeln
formEdit[0][0] = EditYo1;
formEdit[1][0] = EditTu1;
formEdit[2][0] = EditEl1;
@@ -83,9 +83,9 @@ KVerbosDoc* KVerbosView::getDocument() const
return theApp->getDocument();
}
-void KVerbosView::print(QPrinter *pPrinter)
+void KVerbosView::print(TQPrinter *pPrinter)
{
- QPainter printpainter;
+ TQPainter printpainter;
printpainter.begin(pPrinter);
// TODO: add your printing code here
@@ -94,14 +94,14 @@ void KVerbosView::print(QPrinter *pPrinter)
}
// This funktion erases all accents from the letters of a string
-QString KVerbosView::deleteAccents(const QString& s) const
+TQString KVerbosView::deleteAccents(const TQString& s) const
{
- QString s2 = s.simplifyWhiteSpace();
+ TQString s2 = s.simplifyWhiteSpace();
if (!s2.isEmpty())
{
for (unsigned int i=0; i<s2.length(); i++)
{
- QString t = s2.mid(i, 1);
+ TQString t = s2.mid(i, 1);
if (t == "á") s2.replace(i, 1, "a");
if (t == "é") s2.replace(i, 1, "e");
if (t == "í") s2.replace(i, 1, "i");
@@ -115,7 +115,7 @@ QString KVerbosView::deleteAccents(const QString& s) const
void KVerbosView::slotN()
{
- QLineEdit* pl = dynamic_cast<QLineEdit*>(focusWidget());
+ TQLineEdit* pl = dynamic_cast<TQLineEdit*>(focusWidget());
if (pl)
{
pl->insert("ñ");
@@ -124,7 +124,7 @@ void KVerbosView::slotN()
void KVerbosView::slotA()
{
- QLineEdit* pl = dynamic_cast<QLineEdit*>(focusWidget());
+ TQLineEdit* pl = dynamic_cast<TQLineEdit*>(focusWidget());
if (pl)
{
pl->insert("á");
@@ -133,7 +133,7 @@ void KVerbosView::slotA()
void KVerbosView::slotE()
{
- QLineEdit* pl = dynamic_cast<QLineEdit*>(focusWidget());
+ TQLineEdit* pl = dynamic_cast<TQLineEdit*>(focusWidget());
if (pl)
{
pl->insert("é");
@@ -142,7 +142,7 @@ void KVerbosView::slotE()
void KVerbosView::slotI()
{
- QLineEdit* pl = dynamic_cast<QLineEdit*>(focusWidget());
+ TQLineEdit* pl = dynamic_cast<TQLineEdit*>(focusWidget());
if (pl)
{
pl->insert("í");
@@ -151,7 +151,7 @@ void KVerbosView::slotI()
void KVerbosView::slotO()
{
- QLineEdit* pl = dynamic_cast<QLineEdit*>(focusWidget());
+ TQLineEdit* pl = dynamic_cast<TQLineEdit*>(focusWidget());
if (pl)
{
pl->insert("ó");
@@ -160,7 +160,7 @@ void KVerbosView::slotO()
void KVerbosView::slotU()
{
- QLineEdit* pl = dynamic_cast<QLineEdit*>(focusWidget());
+ TQLineEdit* pl = dynamic_cast<TQLineEdit*>(focusWidget());
if (pl)
{
pl->insert("ú");
@@ -171,8 +171,8 @@ void KVerbosView::slotU()
// gesetzt werden, damit die korrigierten Felder wieder die normale Schrift erhalten.
void KVerbosView::slotClearAll()
{
- QFont fontNormal = EditVerbo->font();
- QPalette palette = EditVerbo->palette();
+ TQFont fontNormal = EditVerbo->font();
+ TQPalette palette = EditVerbo->palette();
EditAleman->clear();
EditAleman->setFont(fontNormal);
EditAleman->setPalette(palette);
@@ -245,12 +245,12 @@ void KVerbosView::slotWeiter()
void KVerbosView::slotCorregir()
{
bool richtig = true;
- QFont fontNormal = EditVerbo->font();
- QFont fontBold = EditVerbo->font();
+ TQFont fontNormal = EditVerbo->font();
+ TQFont fontBold = EditVerbo->font();
fontBold.setUnderline(true);
- QPalette palette = EditVerbo->palette();
- palette.setColor(QColorGroup::Text, red);
- palette.setColor(QColorGroup::Base, white);
+ TQPalette palette = EditVerbo->palette();
+ palette.setColor(TQColorGroup::Text, red);
+ palette.setColor(TQColorGroup::Base, white);
if ( 0 > formen[6][1].find(EditAleman->text().simplifyWhiteSpace(), 0))
{
EditAleman->setFont(fontBold);
@@ -278,8 +278,8 @@ void KVerbosView::slotCorregir()
}
else
{
- QString s1 = formEdit[i][j]->text().simplifyWhiteSpace();
- QString s2 = formen[i][j];
+ TQString s1 = formEdit[i][j]->text().simplifyWhiteSpace();
+ TQString s2 = formen[i][j];
if (deleteAccents(s1) != deleteAccents(s2))
{
formEdit[i][j]->setFont(fontBold);
@@ -309,7 +309,7 @@ void KVerbosView::slotCorregir()
// Die Lösung soll in dem Fenster präsentiert werden.
void KVerbosView::slotSolution()
{
- QFont fontNormal = EditVerbo->font();
+ TQFont fontNormal = EditVerbo->font();
EditAleman->setFont(fontNormal);
EditAleman->setPalette(EditVerbo->palette());
EditAleman->setText(formen[6][1]);
@@ -331,8 +331,8 @@ void KVerbosView::slotFont()
{
if (corrected)
{
- QFont fontNormal = EditVerbo->font();
- QLineEdit* pl = dynamic_cast<QLineEdit*>(focusWidget());
+ TQFont fontNormal = EditVerbo->font();
+ TQLineEdit* pl = dynamic_cast<TQLineEdit*>(focusWidget());
if (0 != pl)
{
pl->setFont(fontNormal);
@@ -356,7 +356,7 @@ void KVerbosView::slotCopyText()
formEdit[i][2]->setText(s);
if (corrected)
{
- QFont fontNormal = EditVerbo->font();
+ TQFont fontNormal = EditVerbo->font();
formEdit[i][2]->setFont(fontNormal);
};
};
@@ -33,11 +33,11 @@
// Hier wird gesetzt, wie der Hintergrund des Fensters zu zeichnen ist.
setBackgroundMode(PaletteBackground);
- // Die gesamten Zeiger auf QLineEdit in ein Feld umwandeln
+ // Die gesamten Zeiger auf TQLineEdit in ein Feld umwandeln
formEdit[0][0] = EditYo1;
formEdit[1][0] = EditTu1;
diff --git a/kverbos/kverbos/kverbosview.h b/kverbos/kverbos/kverbosview.h
index cfc4c702..3690c72a 100644
--- a/kverbos/kverbos/kverbosview.h
+++ b/kverbos/kverbos/kverbosview.h
@@ -34,7 +34,7 @@
//class KVerbosDoc;
/** The KVerbosView class provides the view widget for the KVerbosApp instance.
* The View instance inherits QWidget as a base class and represents the view object of a KTMainWindow. As KVerbosView is part of the
* docuement-view model, it needs a reference to the document object connected with it by the KVerbosApp class to manipulate and display
* the document structure provided by the KVerbosDoc class.
*
@@ -57,12 +57,12 @@
* @author Source Framework Automatically Generated by KDevelop, (c) The KDevelop Team.
* @version KDevelop version 0.4 code generation
*/
-class KVerbosView : public QLernen /*QWidget*/
+class KVerbosView : public QLernen /*TQWidget*/
{
Q_OBJECT
public:
/** Constructor for the main view */
- KVerbosView(QWidget *parent = 0, const char *name=0);
+ KVerbosView(TQWidget *parent = 0, const char *name=0);
/** Destructor for the main view */
~KVerbosView();
@@ -74,10 +74,10 @@ public:
KVerbosDoc* getDocument() const;
/** contains the implementation for printing functionality */
- void print(QPrinter *pPrinter);
+ void print(TQPrinter *pPrinter);
/** This funktion erases all accents from the letters of a string
*/
- QString deleteAccents(const QString& s) const;
+ TQString deleteAccents(const TQString& s) const;
/** tell the view that the user has changed. Training results are deleted and set to the
* initial values. A new verb is chosen. The function returns the training result of the
* old user. r1 is the training results and r2 is the number of the trained verbs.
@@ -131,14 +131,14 @@ private:
/** the following variables store the information about the actual verb. The information
* is obtained from the doc.
*/
- QString espanol;
- QString aleman;
+ TQString espanol;
+ TQString aleman;
int zeitAuswahl;
- QString formen[7][3];
+ TQString formen[7][3];
/** tells if the actual input already has been correced by using the button */
bool corrected;
/** Are pointers to the GUI elements for an easier use */
- QLineEdit* formEdit[6][3];
+ TQLineEdit* formEdit[6][3];
/** the number of verbs that habe been correct */
int enteredCorrect;
/** the number of all verbs that have been trained */
@@ -34,7 +34,7 @@
//class KVerbosDoc;
/** The KVerbosView class provides the view widget for the KVerbosApp instance.
- * The View instance inherits QWidget as a base class and represents the view object of a KTMainWindow. As KVerbosView is part of the
+ * The View instance inherits TQWidget as a base class and represents the view object of a KTMainWindow. As KVerbosView is part of the
* docuement-view model, it needs a reference to the document object connected with it by the KVerbosApp class to manipulate and display
* the document structure provided by the KVerbosDoc class.
diff --git a/kverbos/kverbos/verbspanish.cpp b/kverbos/kverbos/verbspanish.cpp
index 8f292419..3fa76dc6 100644
--- a/kverbos/kverbos/verbspanish.cpp
+++ b/kverbos/kverbos/verbspanish.cpp
@@ -50,8 +50,8 @@ endingsArray verbSpanish::verbEndings = { { {"o", "as", "a", "amos", "áis", "an"
{"+", "+", "+", "+", "+", "+"}}
};
-QString verbSpanish::refPron[PERSONEN] = {"me", "te", "se", "nos", "os", "se"};
-QString verbSpanish::estar[MAX_TIEMPOS][PERSONEN] =
+TQString verbSpanish::refPron[PERSONEN] = {"me", "te", "se", "nos", "os", "se"};
+TQString verbSpanish::estar[MAX_TIEMPOS][PERSONEN] =
{ {"estoy", "estás", "está", "estamos", "estáis", "están"},
{"estaba", "estabas", "estaba", "estábamos", "estabais", "estaban"},
{"estuve", "estuviste", "estuvo", "estuvimos", "estuvisteis", "estuvieron"},
@@ -64,7 +64,7 @@ QString verbSpanish::estar[MAX_TIEMPOS][PERSONEN] =
{"", "está", "esté", "estemos", "estad", "estén"}
};
-QString verbSpanish::haber[MAX_TIEMPOS][PERSONEN] =
+TQString verbSpanish::haber[MAX_TIEMPOS][PERSONEN] =
{ {"he", "has", "ha", "hemos", "habéis", "han"},
{"había", "habías", "había", "habíamos", "habíais", "habían"},
{"hube", "hubiste", "hubo", "hubimos", "hubisteis", "hubieron"},
@@ -77,7 +77,7 @@ QString verbSpanish::haber[MAX_TIEMPOS][PERSONEN] =
{"", "he", "haya", "hayamos", "habed", "hayan"}
};
-QString verbSpanish::timeNames[MAX_TIEMPOS*MAX_SUBTYPES] =
+TQString verbSpanish::timeNames[MAX_TIEMPOS*MAX_SUBTYPES] =
{"presente", "imperfecto", "indefinido", "futuro", "condicional",
"subjuntivo presente", "subjuntivo pasado", "subjuntivo futuro", "imperativo",
"presente progresivo", "imperfecto progresivo", "indefinido progresivo", "futuro progresivo", "condicional progresivo",
@@ -86,7 +86,7 @@ QString verbSpanish::timeNames[MAX_TIEMPOS*MAX_SUBTYPES] =
"subjuntivo presente perfecto", "subjuntivo pasado perfecto", "subjuntivo futuro perfecto", "error:form doesn't exist",
};
-QString verbSpanish::groupNames[MAX_GRUPPEN] =
+TQString verbSpanish::groupNames[MAX_GRUPPEN] =
{"regular", "irregular", "e > ie", "o > ue", "u > ue", "e > i",
"c > qu", "g > gu", "z > c", "gu > gü", "c > z", "g > j",
"gu > g", "qu > c", "accent like 'enviar'",
@@ -196,8 +196,8 @@ bool verbSpanish::operator== (const verbSpanish& v) const
return ((spanish == v.spanish) && vergleich(foreign, v.foreign));
}
-// prüft ob der QString mit der spanischen Form übereinstimmt.
-bool verbSpanish::operator== (const QString& s) const
+// prüft ob der TQString mit der spanischen Form übereinstimmt.
+bool verbSpanish::operator== (const TQString& s) const
{
return (spanish == s);
}
@@ -257,18 +257,18 @@ bool verbSpanish::isEmpty() const
// Gibt den Verbstamm zurück. Dazu werden die letzten beiden Zeichen abgetrennt,
// handelt es sich um ein reflexives Verb, dann sind es vier Zeichen.
// Hier werden auch die Stammveränderungen der Gruppenverben durchgeführt.
-QString verbSpanish::getStem() const
+TQString verbSpanish::getStem() const
{
int ab = 2;
if (isReflexiv())
ab += 2;
- QString s = spanish;
+ TQString s = spanish;
s.truncate(s.length()-ab);
return s;
}
// gibt das Verb in der nicht spanischen Sprache zurück
-QString verbSpanish::getForeign() const
+TQString verbSpanish::getForeign() const
{
return foreign;
}
@@ -280,27 +280,27 @@ QString verbSpanish::getForeign() const
// code umgewandelt wird.
// Es wird nicht geprüft, ob der string keine Leerzeichen mehr enthält, denn das
// dürfte eigentlich nicht vorkommen.
-void verbSpanish::setForeign(const QString &s)
+void verbSpanish::setForeign(const TQString &s)
{
foreign = s.simplifyWhiteSpace();
}
// gibt das Verb auf spanisch zurück
-QString verbSpanish::getSpanish() const
+TQString verbSpanish::getSpanish() const
{
return spanish;
}
// Setzt die spanische Bedeutung des Verbes.
// Siehe auch die Bemerkungen zur Arbeitsweise der Funktionbei der setForeign Funktion.
-void verbSpanish::setSpanish(const QString &s)
+void verbSpanish::setSpanish(const TQString &s)
{
spanish = s.simplifyWhiteSpace();
}
// gibt die Gerundform des Verbes zurück. Dabei gilt: Alle Gruppenverben haben einen
// regelmäßigen Gerund. Nur die irregulären Verben haben eventuell auch eine andere Gerundform
-QString verbSpanish::getGerund()
+TQString verbSpanish::getGerund()
{
if (!conjugated)
conjugateAll();
@@ -309,14 +309,14 @@ QString verbSpanish::getGerund()
// setzt die Gerundform des Verbes
// Siehe auch die Bemerkungen zur Arbeitsweise der Funktionbei der setForeign Funktion.
-void verbSpanish::setGerund(const QString &s)
+void verbSpanish::setGerund(const TQString &s)
{
gerund = s.simplifyWhiteSpace();
}
// gibt die Partizipform der Verbes zurück.Dabei gilt: Alle Gruppenverben haben ein
// regelmäßiges Partizip. Nur die irregulären Verben haben eventuell auch eine andere Partizipform
-QString verbSpanish::getPartizip()
+TQString verbSpanish::getPartizip()
{
if (!conjugated)
conjugateAll();
@@ -325,7 +325,7 @@ QString verbSpanish::getPartizip()
// setzt die Partizipform der Verbes
// Siehe auch die Bemerkungen zur Arbeitsweise der Funktionbei der setForeign Funktion.
-void verbSpanish::setPartizip(const QString &s)
+void verbSpanish::setPartizip(const TQString &s)
{
partizip = s.simplifyWhiteSpace();
}
@@ -336,7 +336,7 @@ endings verbSpanish::getEnding(bool& good)
if (spanish.isEmpty())
return empty;
endings en = empty;
- QString endung = "";
+ TQString endung = "";
if (isReflexiv())
{
endung = spanish.mid(spanish.length()-4, 2);
@@ -375,7 +375,7 @@ bool verbSpanish::isReflexiv() const
}
// gibt das Reflexivpronomen zurück, das zu der angegebenen Person gehört.
-QString verbSpanish::getRefPron(int i)
+TQString verbSpanish::getRefPron(int i)
{
return refPron[i];
}
@@ -396,7 +396,7 @@ void verbSpanish::setGroup(const int g)
// die Person p und den Untertyp typ angegeben wird. Mit dieser Funktion können auch
// die zusammengesetzten Zeitforms erfragt werden.
// parts[0] = ref. Pron. part[1] = Hilfsverb parts[2] = verb
-bool verbSpanish::getForm(int t, int p, int typ, QString parts[])
+bool verbSpanish::getForm(int t, int p, int typ, TQString parts[])
{
bool good = !error;
if (good)
@@ -438,9 +438,9 @@ bool verbSpanish::getForm(int t, int p, int typ, QString parts[])
}
// Eine überladene Funktion, die einen String zurückgibt.
-QString verbSpanish::getForm(int t, int p)
+TQString verbSpanish::getForm(int t, int p)
{
- QString st[3];
+ TQString st[3];
if (getForm(t, p, normal, st))
return st[2];
return "";
@@ -448,7 +448,7 @@ QString verbSpanish::getForm(int t, int p)
// setzt die angegebene Verbform mit int als Parameter
// Siehe auch die Bemerkungen zur Arbeitsweise der Funktion bei der setForeign Funktion.
-void verbSpanish::setForm(int t, int p, QString s)
+void verbSpanish::setForm(int t, int p, TQString s)
{
forms[t][p] = s.simplifyWhiteSpace();
}
@@ -456,7 +456,7 @@ void verbSpanish::setForm(int t, int p, QString s)
// bildet die Formen, d.h. hängt die Endungen an den unveränderlichen
// Teil an.
// Die Form muss bisher ein leerer String sein.
-bool verbSpanish::conjugateTime(const int t, const QString &s)
+bool verbSpanish::conjugateTime(const int t, const TQString &s)
{
bool good = true;
for (int i = yo; i <=ellos; i++)
@@ -475,7 +475,7 @@ bool verbSpanish::conjugateTime(const int t, const QString &s)
// dazu wird an den Verbstamm die entsprechende Endung angehängt
bool verbSpanish::conjugatePresente()
{
- QString s = getStem();
+ TQString s = getStem();
return conjugateTime(presente, s);
}
@@ -483,7 +483,7 @@ bool verbSpanish::conjugatePresente()
// dazu wird an den Verbstamm die entsprechende Endung angehängt
bool verbSpanish::conjugateImperfecto()
{
- QString s = getStem();
+ TQString s = getStem();
return conjugateTime(imperfecto, s);
}
@@ -491,7 +491,7 @@ bool verbSpanish::conjugateImperfecto()
// dazu wird an den Verbstamm die entsprechende Endung angehängt
bool verbSpanish::conjugateIndefinido()
{
- QString s = getStem();
+ TQString s = getStem();
return conjugateTime(indefinido, s);
}
@@ -500,7 +500,7 @@ bool verbSpanish::conjugateIndefinido()
// Verben muss das 'se' abgetrennt werden.
bool verbSpanish::conjugateFuturo()
{
- QString s = getSpanish();
+ TQString s = getSpanish();
if (isReflexiv())
s = s.left(s.length()-2);
return conjugateTime(futuro, s);
@@ -510,7 +510,7 @@ bool verbSpanish::conjugateFuturo()
// diese Formen werden ebenfalls vom Infinitiv des Verbes abgeleitet
bool verbSpanish::conjugateCondicional()
{
- QString s = getSpanish();
+ TQString s = getSpanish();
if (isReflexiv())
s = s.left(s.length()-2);
return conjugateTime(condicional, s);
@@ -602,7 +602,7 @@ bool verbSpanish::conjugateAll()
// Stringvergleich, bei dem es nur auf ähnlich Bestandteile ankommt.
// Bestandteile sind durch Komma getrennt.
-bool verbSpanish::vergleich(const QString& s1, const QString& s2) const
+bool verbSpanish::vergleich(const TQString& s1, const TQString& s2) const
{
bool gleich=false;
unsigned int l=0;
@@ -625,7 +625,7 @@ bool verbSpanish::vergleich(const QString& s1, const QString& s2) const
}
// returns true if the form is automatic generated and has a '#' on the right end.
-bool verbSpanish::isAutoForm(QString& s) const
+bool verbSpanish::isAutoForm(TQString& s) const
{
if ("#" == s.right(1))
return true;
@@ -633,7 +633,7 @@ bool verbSpanish::isAutoForm(QString& s) const
}
// löscht das '#' einer automatisch generierten Form
-QString verbSpanish::delAutoForm(QString s) const
+TQString verbSpanish::delAutoForm(TQString s) const
{
if (isAutoForm(s))
s = s.left(s.length()-1);
@@ -660,7 +660,7 @@ QString verbSpanish::delAutoForm(QString s) const
// 15 -> <accent like 'continuar'>
// 16 -> <missing i>
//
-bool verbSpanish::groupVerb(QString &s, int time/*=-1*/, int person/*=-1*/)
+bool verbSpanish::groupVerb(TQString &s, int time/*=-1*/, int person/*=-1*/)
{
bool good = true;
int pos;
@@ -718,7 +718,7 @@ bool verbSpanish::groupVerb(QString &s, int time/*=-1*/, int person/*=-1*/)
// alle subjuntivo Formen und den imperativo
if ((presente == time) && (person != nosotros) && (person != vosotros))
{
- QString st = getStem();
+ TQString st = getStem();
pos = st.findRev("e");
if (pos>=0)
{
@@ -729,7 +729,7 @@ bool verbSpanish::groupVerb(QString &s, int time/*=-1*/, int person/*=-1*/)
else
if ((indefinido == time) && ((el == person)||(ellos == person)))
{
- QString st = getStem();
+ TQString st = getStem();
pos = st.findRev("e");
if (pos>=0)
{
diff --git a/kverbos/kverbos/verbspanish.h b/kverbos/kverbos/verbspanish.h
index 8b7cf7b1..f621718d 100644
--- a/kverbos/kverbos/verbspanish.h
+++ b/kverbos/kverbos/verbspanish.h
@@ -19,7 +19,7 @@
#define VERBSPANISH_H
// include qt-Header
-#include <qvaluelist.h>
+#include <tqvaluelist.h>
#define MAX_TIEMPOS 9
#define MAX_SUBTYPES 3
@@ -41,8 +41,8 @@ enum timeTypes {presente, imperfecto, indefinido, futuro, condicional, subPresen
enum timeSubTypes {normal, progresivo, perfecto};
enum persons {yo, tu, el, nosotros, vosotros, ellos};
-typedef QString formArray[MAX_TIEMPOS][PERSONEN];
-typedef QString endingsArray[MAX_TIEMPOS][VERBMUSTER][PERSONEN];
+typedef TQString formArray[MAX_TIEMPOS][PERSONEN];
+typedef TQString endingsArray[MAX_TIEMPOS][VERBMUSTER][PERSONEN];
/** This class contains all the information belonging to one verb:
*
@@ -93,13 +93,13 @@ typedef QString endingsArray[MAX_TIEMPOS][VERBMUSTER][PERSONEN];
* The conjugated forms of the verb are stored in the array 'formArray'. The first index
* mentions the time and the second the person.
* <pre>
- * typedef QString formArray[MAX_TIEMPOS][PERSONEN];
+ * typedef TQString formArray[MAX_TIEMPOS][PERSONEN];
* </pre>
*
* The type 'endingsArray' stores the different endings. The first index means the time,
* the second the type of verb (-ar, -er, -ir) and the lase one is the person.
* <pre>
- * typedef QString endingsArray[MAX_TIEMPOS][MAX_SUBTYPES][PERSONEN];
+ * typedef TQString endingsArray[MAX_TIEMPOS][MAX_SUBTYPES][PERSONEN];
* </pre>
*
* The verbs are divided in several groups:
@@ -132,10 +132,10 @@ public:
verbSpanish& operator= (const verbSpanish& v);
/** If two verbs are compared only the foreign form and the spanish form are compared */
bool operator== (const verbSpanish& v) const;
/** This overloaded == operator compares the verb to a QString.
* Only the spanish meaning is compared.
*/
- bool operator== (const QString& s) const;
+ bool operator== (const TQString& s) const;
/** The spa/nisch forms of the verb are compared */
bool operator< (const verbSpanish& v) const;
/** Compares the verb objects completely, all forms and fields.
@@ -146,28 +146,28 @@ public:
bool isEmpty() const;
/** returns the foreign meaning of the verb
*/
- QString getForeign() const;
+ TQString getForeign() const;
/** sets the foreign meaning of the verb
*/
- void setForeign(const QString &s);
+ void setForeign(const TQString &s);
/** returns the spanish meaning of the verb
*/
- QString getSpanish() const;
+ TQString getSpanish() const;
/** sets the spanish meaning of the verb
*/
- void setSpanish(const QString &s);
+ void setSpanish(const TQString &s);
/** returns the gerund of the verb
*/
- QString getGerund();
+ TQString getGerund();
/** sets the gerund form to the string given in s
*/
- void setGerund(const QString &s);
+ void setGerund(const TQString &s);
/** returns the particip of the verb
*/
- QString getPartizip();
+ TQString getPartizip();
/** sets the participe to the string given in s
*/
- void setPartizip(const QString &s);
+ void setPartizip(const TQString &s);
/** returns if the verb belongs to one of the groups
*/
bool isGroupVerb();
@@ -186,13 +186,13 @@ public:
* parts[2] the verb form
* The return value 'bool' indicates if the form could be formed.
*/
- bool getForm(int t, int p, int typ, QString parts[]);
+ bool getForm(int t, int p, int typ, TQString parts[]);
/** returns the desired verb form indicated by time and person as a string
*/
- QString getForm(int t, int p);
+ TQString getForm(int t, int p);
/** sets the verb form that is indicated by time and person
*/
- void setForm(int t, int p, QString s);
+ void setForm(int t, int p, TQString s);
/** The following function generates the regular verb forms. The forms can be
* generated time by time or all times in one step by using conjugateAll()
*/
@@ -202,9 +202,9 @@ public:
bool isReflexiv() const;
/** returns the reflexive pronoun that belongs to the person p
*/
- QString getRefPron(int p);
+ TQString getRefPron(int p);
/** tests if the string is an automatic generated Form, that means the last char is '#' */
- bool isAutoForm(QString& s) const;
+ bool isAutoForm(TQString& s) const;
private:
bool conjugatePresente();
bool conjugateImperfecto();
@@ -216,7 +216,7 @@ private:
bool conjugateImperativo();
/** returns the verb stem
*/
- QString getStem() const;
+ TQString getStem() const;
/** returns the ending of the verb
*/
endings getEnding(bool& good);
@@ -226,7 +226,7 @@ private:
* bereits eine gültige Form vorliegt und diese Form eine unregelmäßige Form ist, die
* nicht überschrieben werden soll.
*/
- bool conjugateTime(const int t, const QString &s);
+ bool conjugateTime(const int t, const TQString &s);
/** Es wird verglichen, ob die beiden Strings gemeinsame Bestandteile haben. Also
* "gehen, laufen, springen" wird etwa mit "gehen, laufen" verglichen. Die Funktion
* gibt in so einem Fall 'true' zurück, auch wenn im zweiten String ein Teil
@@ -234,24 +234,24 @@ private:
* mehr oder weniger deutsche Bedeutungen oder die Bedeutungen in anderer Reihenfolge
* angegeben sind.
*/
- bool vergleich(const QString& s1, const QString& s2) const;
+ bool vergleich(const TQString& s1, const TQString& s2) const;
/** Deletes the '#' character from autogenerated forms. */
- QString delAutoForm(QString s) const;
+ TQString delAutoForm(TQString s) const;
/** does the changes for group verbs
*/
- bool groupVerb(QString &s, int time=-1, int person=-1);
+ bool groupVerb(TQString &s, int time=-1, int person=-1);
/** the verb in the foreign language
*/
- QString foreign;
+ TQString foreign;
/** the spanish verb
*/
- QString spanish;
+ TQString spanish;
/** the gerund form of the verb
*/
- QString gerund;
+ TQString gerund;
/** the partizip form of the verb
*/
- QString partizip;
+ TQString partizip;
/** the array for all the different forms of the verb
*/
formArray forms;
@@ -270,32 +270,32 @@ private:
static endingsArray verbEndings;
/** the reflexive pronouns
*/
- static QString refPron[PERSONEN];
+ static TQString refPron[PERSONEN];
public:
/** The forms of the verb estar. They are needed for the gerund form.
*/
- static QString estar[MAX_TIEMPOS][PERSONEN];
+ static TQString estar[MAX_TIEMPOS][PERSONEN];
/** The forms of the verb haber. They are needed for perfect forms
*/
- static QString haber[MAX_TIEMPOS][PERSONEN];
+ static TQString haber[MAX_TIEMPOS][PERSONEN];
/** This array contains the names of the time forms as strings
*/
- static QString timeNames[MAX_TIEMPOS*MAX_SUBTYPES];
+ static TQString timeNames[MAX_TIEMPOS*MAX_SUBTYPES];
/** This array contains the names of the different verb groups
*/
- static QString groupNames[MAX_GRUPPEN];
+ static TQString groupNames[MAX_GRUPPEN];
static int maxTiempos;
static int maxSubtypes;
static int persons;
static int maxForms;
/** The language that is selected at the moment. This selection affects all the instances
* of the class. */
- static QString language;
+ static TQString language;
};
/** Very often a list of verbs is needed. This is the type definition of a
* QValueList template with the verbSpanish type
*/
-typedef QValueList<verbSpanish> spanishVerbList;
+typedef TQValueList<verbSpanish> spanishVerbList;
#endif
@@ -132,10 +132,10 @@ public:
/** If two verbs are compared only the foreign form and the spanish form are compared */
bool operator== (const verbSpanish& v) const;
- /** This overloaded == operator compares the verb to a QString.
+ /** This overloaded == operator compares the verb to a TQString.
* Only the spanish meaning is compared.
*/
@@ -270,32 +270,32 @@ private:
};
/** Very often a list of verbs is needed. This is the type definition of a
- * QValueList template with the verbSpanish type
+ * TQValueList template with the verbSpanish type
*/